@@ -7,18 +7,20 @@
 #include "crash.h"
 /*#include <linux/tasks.h>*/
 
-PRIVATE addr_t task(), fs_struct(), mm_struct();
-const commandtable_t
-	command_task_struct =
-	{"task_struct", task, "[-f] [address]", "print task_struct table"},
-	command_fs_struct =
-	{"fs_struct", fs_struct, "address", "print fs_struct"},
-	command_mm_struct =
-	{"mm_struct", mm_struct, "[-v] address", "print mm_struct\n  -v  show vm_area_struct"};
+PRIVATE addr_t task(), fs_struct(), mm_struct(), files_struct();
+const commandtable_t command_task_struct =
+	{"task_struct", task, "[-f] [address]", "print task_struct table"};
+const commandtable_t command_fs_struct =
+	{"fs_struct", fs_struct, "address", "print fs_struct table"};
+const commandtable_t command_mm_struct =
+	{"mm_struct", mm_struct, "[-v] address", "print mm_struct table\n  -v  show vm_area_struct"};
+const commandtable_t command_files_struct =
+	{"files_struct", files_struct, "address", "print files_struct table"};
 
 extern addr_t print_task();
 extern addr_t print_fs_struct();
 extern addr_t print_mm_struct();
+extern addr_t print_files_struct();
 
 addr_t init_task_addr;
 
@@ -103,3 +105,22 @@ mm_struct()
 	}
 	return addr;
 }
+
+PRIVATE addr_t
+files_struct()
+{
+	int c;
+
+	while ((c = getopt(argcnt, args, "")) != EOF) {
+		THROW(usage);
+	}
+
+	if (argcnt == optind) {
+		THROW(usage);
+	}
+	while (args[optind]) {
+		(void)print_files_struct(getaddr(args[optind]));
+		optind++;
+	}
+	return 0;
+}
