@@ -14,6 +14,8 @@
 #include <page_buf.h>
 #endif
 
+#include "flags_pagebuf.h"
+
 extern void prhead_semaphore();
 extern addr_t print_semaphore();
 
@@ -30,43 +32,6 @@ print_pagebuf(addr, fflag)
 	int fflag;
 {
 	page_buf_t pb;
-	static const struct bitname pbflags[] = {
-		{ PBF_READ,		"read" },
-		{ PBF_WRITE,		"write" },
-		{ PBF_MAPPED,		"mapped" },
-		{ PBF_PARTIAL,		"partial" },
-		{ PBF_ASYNC,		"async" },
-		{ PBF_NONE,		"none" },
-		{ PBF_DELWRI,		"delwri" },
-		{ PBF_FREED,		"freed" },
-		{ PBF_SYNC,		"sync" },
-		{ PBF_MAPPABLE,		"mappable" },
-		{ PBF_STALE,		"stale" },
-#if 0
-		{ PBF_FS_MANAGED,	"fs_managed" },
-#endif
-		{ PBF_RELEASE,		"release" },
-
-		{ PBF_LOCK,		"lock" },
-		{ PBF_TRYLOCK,		"trylock" },
-		{ PBF_ALLOCATE,		"allocate" },
-		{ PBF_FILE_ALLOCATE,	"file_allocate" },
-		{ PBF_DONT_BLOCK,	"dont_block" },
-		{ PBF_DIRECT,		"direct" },
-		{ PBF_ENTER_PAGES,	"enter_pages" },
-
-		{ _PBF_LOCKABLE,	"_lockable" },
-		{ _PBF_ALL_PAGES_MAPPED,"_all_pages_mapped" },
-		{ _PBF_SOME_INVALID_PAGES,"_some_invalid_pages" },
-		{ _PBF_ADDR_ALLOCATED,	"_addr_allocated" },
-		{ _PBF_MEM_ALLOCATED,	"_mem_allocated" },
-
-#if 0
-		{ PBF_GRIO,		"grio" },
-#endif
-		{ PBF_FORCEIO,		"forceio" },
-		{ 0,			NULL }
-	};
 
 	memread(addr, sizeof(pb), &pb, "page_buf_t");
 	mprintf(FPTR " ", addr);
@@ -81,7 +46,7 @@ print_pagebuf(addr, fflag)
 	mprintf(" %3x", pb.pb_page_count);
 	mprintf(" %4x", pb.pb_offset);
 	mprintf(" " FPTR, pb.pb_pages);
-	mprintbit(pbflags, pb.pb_flags);
+	mprintbit(page_buf_flags_e_bitname, pb.pb_flags);
 	mprintf("\n");
 
 	if (fflag) {
